@@ -4,8 +4,7 @@
 
 ;; Author: Milan Glacier <dev@milanglacier.com>
 ;; Maintainer: Milan Glacier <dev@milanglacier.com>
-;; Package-Version: 0.2
-;; Package-Revision: v0.2-0-gb69db24ddbcd
+;; Version: 0.2
 ;; URL: https://github.com/milanglacier/termint.el
 ;; Package-Requires: ((emacs "29.1"))
 
@@ -65,6 +64,22 @@
 
 (require 'cl-lib)
 
+(defvar vterm-buffer-name)
+(defvar vterm-shell)
+(declare-function vterm-send-string "vterm")
+(declare-function vterm "vterm")
+
+(defvar eat-buffer-name)
+(defvar eat-shell)
+(declare-function eat "eat")
+(declare-function eat--send-string "eat")
+(declare-function eat--synchronize-scroll "eat")
+
+(declare-function term-exec "term")
+(declare-function term-mode "term")
+(declare-function term-char-mode "term")
+(declare-function term-send-raw-string "term")
+
 (defgroup termint nil
   "Group for termint."
   :group 'tools)
@@ -81,21 +96,54 @@ Note that `eat' and `vterm' must be installed separately."
   '((t :inherit font-lock-comment-face))
   "Face used for displaying hint of source command.")
 
-(defvar vterm-buffer-name)
-(defvar vterm-shell)
-(declare-function vterm-send-string "vterm")
-(declare-function vterm "vterm")
+(defcustom termint-region-dispatchers
+  '(("paragraph" . termint--dispatch-paragraph)
+    ("buffer" . termint--dispatch-buffer)
+    ("defun" . termint--dispatch-defun))
+  "Alist mapping dispatchable region types to dispatcher functions.
+Each element is of the form (NAME . DISPATCHER).  The NAME is appended
+to generated command names (e.g., `termint-ipython-send-NAME' and
+`termint-ipython-source-NAME' for an ipython schema), while DISPATCHER
+should be a function returning a cons cell (BEG . END) for the
+corresponding region.  Customize this before calling `termint-define'
+to generate additional region commands automatically for each REPL
+schema."
+  :type '(alist :key-type string :value-type function))
 
-(defvar eat-buffer-name)
-(defvar eat-shell)
-(declare-function eat "eat")
-(declare-function eat--send-string "eat")
-(declare-function eat--synchronize-scroll "eat")
+(defcustom termint-schema-custom-commands nil
+  "Alist of extra commands generated for each REPL schema.
+Each element takes the form (SUFFIX . FN).  SUFFIX is a string
+appended to `termint-REPL-NAME-` to create the final command name for
+every schema defined via `termint-define'.  FN is the function invoked
+by the generated command.  It receives two arguments: REPL-NAME and
+SESSION.  See `termint--hide-window' for a reference implementation of
+the expected function signature.
 
-(declare-function term-exec "term")
-(declare-function term-mode "term")
-(declare-function term-char-mode "term")
-(declare-function term-send-raw-string "term")
+For example, to generate a command named `termint-ipython-hide-window',
+add the entry `(\"hide-window\" . termint--hide-window)' to this list.
+
+Configure this variable before
+invoking `termint-define' to ensure the custom commands are
+generated."
+  :type '(alist :key-type string :value-type function))
+
+(defcustom termint-mode-map-additional-keys
+  '(("f" . "send-defun")
+    ("F" . "source-defun")
+    ("b" . "send-buffer")
+    ("B" . "source-buffer")
+    ("p" . "send-paragraph")
+    ("P" . "source-paragraph"))
+  "Alist of keys and command suffixes to add to generated REPL keymaps.
+Each element is a cons cell of the form (KEY . SUFFIX).  KEY is the
+string sequence to bind.  SUFFIX is a string appended to
+`termint-REPL-NAME-' to resolve the actual command symbol (e.g.,
+\"send-defun\" becomes `termint-ipython-send-defun' when defining an
+ipython REPL).  This variable should be modified before calling
+`termint-define' to affect the generated keymaps."
+  :type '(alist :key-type string :value-type string))
+
+
 
 (defun termint--get-session-suffix (session)
   "Return the session suffix from SESSION if interactive spec is \"P\"."
@@ -120,7 +168,6 @@ buffer name."
       ('term
        (termint--start-term-backend repl-buffer-name repl-shell session)))))
 
-
 (defun termint--rearrange-session-on-buffer-exit ()
   "Renumber sibling REPL sessions.
 This function is called after one session is killed to maintain
@@ -145,7 +192,6 @@ without a number is considered as session 0."
                        (rename-buffer (format "*%s*" repl-name))
                      (rename-buffer (format "*%s*<%d>" repl-name idx))))))))
 
-
 (defun termint--start-term-backend (repl-buffer-name repl-shell session)
   "Start REPL-SHELL in REPL-BUFFER-NAME with numeric SESSION with term backend."
   (require 'term)
@@ -200,8 +246,7 @@ without a number is considered as session 0."
                  #'termint--rearrange-session-on-buffer-exit
                  t)))
 
-
-
+
 
 (defun termint--send-string
     (string
@@ -327,47 +372,6 @@ line of that matches SOURCE-COMMAND."
       (message "No defun found at point")
       nil)))
 
-(defcustom termint-region-dispatchers
-  '(("paragraph" . termint--dispatch-paragraph)
-    ("buffer" . termint--dispatch-buffer)
-    ("defun" . termint--dispatch-defun))
-  "Alist mapping dispatchable region types to dispatcher functions.
-Each element is of the form (NAME . DISPATCHER).  The NAME is appended
-to generated command names (e.g., `termint-ipython-send-NAME' and
-`termint-ipython-source-NAME' for an ipython schema), while DISPATCHER
-should be a function returning a cons cell (BEG . END) for the
-corresponding region.  Customize this before calling `termint-define'
-to generate additional region commands automatically for each REPL
-schema."
-  :type '(alist :key-type string :value-type function))
-
-(defcustom termint-schema-custom-commands nil
-  "Alist of extra commands generated for each REPL schema.
-Each element takes the form (SUFFIX . FN).  SUFFIX is a string
-appended to `termint-REPL-NAME-` to create the final command name for
-every schema defined via `termint-define`.  FN is the function invoked
-by the generated command.  It receives two arguments: REPL-NAME and
-SESSION.  See `termint--hide-window` for a reference implementation of
-the expected function signature.  Configure this variable before
-invoking `termint-define` to ensure the custom commands are
-generated."
-  :type '(alist :key-type string :value-type function))
-
-(defvar termint-mode-map-additional-keys
-  '(("f" . "send-defun")
-    ("F" . "source-defun")
-    ("b" . "send-buffer")
-    ("B" . "source-buffer")
-    ("p" . "send-paragraph")
-    ("P" . "source-paragraph"))
-  "Alist of keys and command suffixes to add to generated REPL keymaps.
-Each element is a cons cell of the form (KEY . SUFFIX).  KEY is the
-string sequence to bind.  SUFFIX is a string appended to
-`termint-REPL-NAME-' to resolve the actual command symbol (e.g.,
-\"send-defun\" becomes `termint-ipython-send-defun' when defining an
-ipython REPL).  This variable should be modified before calling
-`termint-define' to affect the generated keymaps.")
-
 (defun termint--dispatch-region-and-send
     (dispatcher repl-name session source-syntax)
   "Get region via DISPATCHER, optionally transform for sourcing, and send.
@@ -388,9 +392,6 @@ before sending."
         (funcall send-string-func string session))
     (message "Invalid region from dispatcher - nothing sent to REPL")))
 
-
-
-
 (defun termint--hide-window (repl-name session)
   "Hide the REPL window.
 The target REPL buffer is specified by REPL-NAME and SESSION."
@@ -412,10 +413,7 @@ REPL-NAME."
         (replace-regexp-in-string "{{file}}" file source-syntax))
     (funcall source-syntax str)))
 
-
-
-
-
+
 
 (defmacro termint-define (repl-name repl-cmd &rest args)
   "Define a REPL schema.
@@ -719,6 +717,8 @@ ensure that the file is not deleted.  In these cases, pass
 as a string, the temporary file will be automatically deleted
 afterward.")
 
+
+
 (defvar termint-ipython-source-syntax-template
   "%run -i \"{{file}}\""
   "The template syntax used to source code content into the iPython REPL.
